@@ -193,7 +193,8 @@ class API:
             )
 
         self.connect_core = connect_core.API(self.config)
-        self._ExistBoardList = []
+        self._exist_board_list = []
+        self._board_info_list = dict()
         self._ModeratorList = dict()
         self._LastThrowWaterBallTime = 0
         self._ThreadID = threading.get_ident()
@@ -473,9 +474,10 @@ class API:
             self,
             board: str,
             check_moderator: bool = False) -> None:
-        if board.lower() not in self._ExistBoardList:
+        if board.lower() not in self._exist_board_list:
             board_info = self._get_board_info(board)
-            self._ExistBoardList.append(board.lower())
+            self._exist_board_list.append(board.lower())
+            self._board_info_list[board.lower()] = board_info
 
             moderators = board_info.moderators
             moderators = [x.lower() for x in moderators]
@@ -1028,7 +1030,44 @@ class API:
 
         self._check_board(board)
 
-        max_push_length = 33
+        board_info = self._board_info_list[board.lower()]
+
+        if board_info.is_push_record_ip:
+            log.log(
+                self.config,
+                log.level.INFO,
+                i18n.record_ip)
+            if board_info.is_push_aligned:
+                log.log(
+                    self.config,
+                    log.level.INFO,
+                    i18n.push_aligned)
+                max_push_length = 32
+            else:
+                log.log(
+                    self.config,
+                    log.level.INFO,
+                    i18n.not_push_aligned)
+                max_push_length = 43 - len(self._ID)
+        else:
+            log.log(
+                self.config,
+                log.level.INFO,
+                i18n.not_record_ip)
+            #     推文對齊
+            if board_info.is_push_aligned:
+                log.log(
+                    self.config,
+                    log.level.INFO,
+                    i18n.push_aligned)
+                max_push_length = 46
+            else:
+                log.log(
+                    self.config,
+                    log.level.INFO,
+                    i18n.not_push_aligned)
+                max_push_length = 58 - len(self._ID)
+
         push_list = []
 
         temp_start_index = 0
@@ -1641,6 +1680,21 @@ class API:
 
         return _api_mail.del_mail(self, index)
 
+    def change_pw(self, new_password):
+        self._one_thread()
+
+        if not self._login_status:
+            raise exceptions.Requirelogin(i18n.Requirelogin)
+
+        new_password = new_password[:8]
+
+        try:
+            from . import _api_change_pw
+        except ModuleNotFoundError:
+            import _api_change_pw
+
+        _api_change_pw.change_pw(self, new_password)
+
 
 if __name__ == '__main__':
     print('PyPtt v ' + version.V)
