@@ -136,12 +136,30 @@ def get_mail(api, index) -> data_type.MailInfo:
     # cmd_list.append(command.Enter)
     cmd = ''.join(cmd_list)
 
+    fast_target = ''
+    for i in range(0, 5):
+        space = ' ' * i
+        fast_target = f'{api.cursor}{space}{index}'
+
+        if api.cursor == data_type.Cursor.NEW:
+            if len(fast_target) == 6:
+                break
+        else:
+            if len(fast_target) == 5:
+                break
+
     target_list = [
         connect_core.TargetUnit(
             i18n.MailBox,
             screens.Target.InMailBox,
             break_detect=True,
             log_level=log.level.DEBUG
+        ),
+        connect_core.TargetUnit(
+            i18n.MailBox,
+            fast_target,
+            break_detect=True,
+            log_level=log.level.DEBUG
         )
     ]
 
@@ -149,16 +167,15 @@ def get_mail(api, index) -> data_type.MailInfo:
         cmd,
         target_list,
     )
-
-    last_screen = api.connect_core.get_screen_queue()[-1]
+    # last_screen = api.connect_core.get_screen_queue()[-1]
     # print(last_screen)
 
     origin_mail, _ = _api_util.get_content(api, post_mode=False)
-    print(origin_mail)
+    # print(origin_mail)
 
     mail_author_pattern = re.compile('作者  (.+)')
     pattern_result = mail_author_pattern.search(origin_mail)
-    mail_author = pattern_result.group(0).strip()
+    mail_author = pattern_result.group(0)[2:].strip()
     log.show_value(
         api.config,
         log.level.DEBUG,
@@ -168,7 +185,7 @@ def get_mail(api, index) -> data_type.MailInfo:
 
     mail_title_pattern = re.compile('標題  (.+)')
     pattern_result = mail_title_pattern.search(origin_mail)
-    mail_title = pattern_result.group(0).strip()
+    mail_title = pattern_result.group(0)[2:].strip()
     log.show_value(
         api.config,
         log.level.DEBUG,
@@ -178,7 +195,7 @@ def get_mail(api, index) -> data_type.MailInfo:
 
     mail_date_pattern = re.compile('時間  (.+)')
     pattern_result = mail_date_pattern.search(origin_mail)
-    mail_date = pattern_result.group(0).strip()
+    mail_date = pattern_result.group(0)[2:].strip()
     log.show_value(
         api.config,
         log.level.DEBUG,
