@@ -39,6 +39,7 @@ Info = None
 Debug = None
 Again = None
 ErrorIDPW = None
+ErrorPW = None
 ScreenNoMatchTarget = None
 SigningUnPleaseWait = None
 Msg = None
@@ -64,6 +65,9 @@ Integer = None
 Boolean = None
 ID = None
 Password = None
+InputOriginPassword = None
+InputNewPassword = None
+CheckNewPassword = None
 Board = None
 IntoBoard = None
 BothInput = None
@@ -114,6 +118,7 @@ VerifyID = None
 TradingInProgress = None
 Transaction = None
 MoneyTooFew = None
+TransactionCancelled = None
 ConstantRedBag = None
 SendMail = None
 Select = None
@@ -158,6 +163,7 @@ MarkPost = None
 DelAllMarkPost = None
 NoSuchPost = None
 GoMainMenu = None
+ErrorLoginRichPeopleGoMainMenu = None
 CanNotUseSearchPostCodeF = None
 FavouriteBoardList = None
 bucket = None
@@ -171,6 +177,11 @@ NoMail = None
 UseMailboxAPIWillLogoutAfterExecution = None
 PicksInRegister = None
 RegisterInProcessing = None
+record_ip = None
+not_record_ip = None
+push_aligned = None
+not_push_aligned = None
+confirm = None
 
 
 def specific_load(input_language, lang_list):
@@ -328,6 +339,12 @@ def load(input_lang):
         'Wrong password or no such id',
     ])
 
+    global ErrorPW
+    ErrorPW = specific_load(input_lang, [
+        '密碼不正確',
+        'Wrong password',
+    ])
+
     global ScreenNoMatchTarget
     ScreenNoMatchTarget = specific_load(input_lang, [
         '畫面無法辨識',
@@ -478,6 +495,24 @@ def load(input_lang):
         'Password',
     ])
 
+    global InputOriginPassword
+    InputOriginPassword = specific_load(input_lang, [
+        '輸入原密碼',
+        'Input Origin Password',
+    ])
+
+    global InputNewPassword
+    InputNewPassword = specific_load(input_lang, [
+        '設定新密碼',
+        'Input New Password',
+    ])
+
+    global CheckNewPassword
+    CheckNewPassword = specific_load(input_lang, [
+        '檢查新密碼',
+        'CheckNewPassword',
+    ])
+
     global Board
     Board = specific_load(input_lang, [
         '看板',
@@ -784,6 +819,12 @@ def load(input_lang):
         'The amount is too small, the transaction is cancelled!',
     ])
 
+    global TransactionCancelled
+    TransactionCancelled = specific_load(input_lang, [
+        '交易取消!',
+        'The transaction is cancelled!',
+    ])
+
     global ConstantRedBag
     ConstantRedBag = specific_load(input_lang, [
         '不修改紅包袋',
@@ -922,7 +963,6 @@ def load(input_lang):
         f'{PTT2} Not Support',
     ])
 
-    # Animation
     global AnimationPost
     AnimationPost = specific_load(input_lang, [
         '動畫文章',
@@ -1049,6 +1089,12 @@ def load(input_lang):
         'Back to main memu',
     ])
 
+    global ErrorLoginRichPeopleGoMainMenu
+    ErrorLoginRichPeopleGoMainMenu = specific_load(input_lang, [
+        '誤入大富翁區，回到主選單',
+        'Stray into the Monopoly area and return to the main menu',
+    ])
+
     global CanNotUseSearchPostCodeF
     CanNotUseSearchPostCodeF = specific_load(input_lang, [
         '此狀態下無法使用搜尋文章代碼(AID)功能',
@@ -1126,7 +1172,36 @@ def load(input_lang):
         '註冊申請單尚在處理中',
         'Register is in processing',
     ])
-    #
+
+    global record_ip
+    record_ip = specific_load(input_lang, [
+        '紀錄 IP',
+        'Record ip',
+    ])
+
+    global not_record_ip
+    not_record_ip = specific_load(input_lang, [
+        '不紀錄 IP',
+        'Not record ip',
+    ])
+
+    global push_aligned
+    push_aligned = specific_load(input_lang, [
+        '推文對齊',
+        'Push aligned',
+    ])
+
+    global not_push_aligned
+    not_push_aligned = specific_load(input_lang, [
+        '無推文對齊',
+        'No push aligned',
+    ])
+
+    global confirm
+    confirm = specific_load(input_lang, [
+        '確認',
+        'Confirm',
+    ])
 
     # No changes have been made to any settings
 
